@@ -3,7 +3,7 @@ package DateTime::Locale::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 use Carp qw( carp );
 use DateTime::Locale;
@@ -485,7 +485,7 @@ DateTime::Locale::Base - Base class for individual locale objects
 
 =head1 VERSION
 
-version 0.95
+version 0.96
 
 =head1 SYNOPSIS
 
@@ -797,20 +797,10 @@ one exists.
 
 See L<DateTime::Locale>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Richard Evans
-
-=item *
+=head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dave Rolsky.
