@@ -3,7 +3,7 @@ package DateTime::Locale::Catalog;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 1;
 
@@ -19,7 +19,7 @@ DateTime::Locale::Catalog - Provides a catalog of all valid locale names
 
 =head1 VERSION
 
-version 0.95
+version 0.96
 
 =head1 DESCRIPTION
 
@@ -759,20 +759,10 @@ The available locales are:
  zu               Zulu                                      isiZulu
  zu-ZA            Zulu South Africa                         isiZulu i-South Africa
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Richard Evans
-
-=item *
+=head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dave Rolsky.
