@@ -5,7 +5,7 @@ use warnings;
 
 use Exporter qw( import );
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 our @EXPORT_OK = 'parse_locale_code';
 
@@ -35,7 +35,7 @@ DateTime::Locale::Util - Utility code for DateTime::Locale
 
 =head1 VERSION
 
-version 0.95
+version 0.96
 
 =head1 DESCRIPTION
 
@@ -43,20 +43,10 @@ There are no user-facing parts in this module.
 
 =encoding UTF-8
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Richard Evans
-
-=item *
+=head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dave Rolsky.
